@@ -108,51 +108,6 @@ panel_orient_change (GtkWidget *widget, gpointer data)
 			      widget);
 }
 
-void
-back_change (AppletInfo  *info,
-	     PanelWidget *panel)
-{
-	switch (info->type) {
-	case PANEL_OBJECT_APPLET:
-		panel_applet_frame_change_background (
-			PANEL_APPLET_FRAME (info->widget), panel->background.type);
-		break;
-	case PANEL_OBJECT_MENU_BAR:
-	case PANEL_OBJECT_USER_MENU:
-		panel_menu_bar_object_change_background (PANEL_MENU_BAR_OBJECT (info->widget));
-		break;
-	case PANEL_OBJECT_SEPARATOR:
-		panel_separator_change_background (PANEL_SEPARATOR (info->widget));
-		break;
-	default:
-		break;
-	}
-}
-
-static void
-back_change_foreach (GtkWidget   *widget,
-		     PanelWidget *panel)
-{
-	AppletInfo *info;
-
-	info = g_object_get_data (G_OBJECT (widget), "applet_info");
-
-	back_change (info, panel);
-}
-
-static void
-panel_back_change (GtkWidget *widget, gpointer data)
-{
-	gtk_container_foreach (GTK_CONTAINER (widget),
-			       (GtkCallback) back_change_foreach,
-			       widget);
-
-#ifdef FIXME_FOR_NEW_CONFIG
-	/*update the configuration box if it is displayed*/
-	update_config_back(PANEL_WIDGET(widget));
-#endif /* FIXME_FOR_NEW_CONFIG */
-}
-
 static void
 panel_applet_added(GtkWidget *widget, GtkWidget *applet, gpointer data)
 {
@@ -161,7 +116,6 @@ panel_applet_added(GtkWidget *widget, GtkWidget *applet, gpointer data)
 	info = g_object_get_data (G_OBJECT (applet), "applet_info");
 
 	orientation_change(info,PANEL_WIDGET(widget));
-	back_change(info,PANEL_WIDGET(widget));
 }
 
 static gboolean
@@ -307,11 +261,16 @@ panel_popup_menu (PanelToplevel *toplevel,
 	panel_data   = g_object_get_data (G_OBJECT (toplevel), "PanelData");
 
 	current_event = gtk_get_current_event ();
+	if (!current_event)
+		return FALSE;
+
 	if (current_event->type == GDK_BUTTON_PRESS)
 		panel_data->insert_pack_type = panel_widget_get_insert_pack_type_at_cursor (panel_widget);
 	else
 		panel_data->insert_pack_type = PANEL_OBJECT_PACK_START;
-	
+
+	gdk_event_free (current_event);
+
 	menu = make_popup_panel_menu (panel_widget);
 	if (!menu)
 		return FALSE;
@@ -361,22 +320,21 @@ panel_key_press_event (PanelToplevel *toplevel,
 }
 
 static GSettings *
-get_settings_background_for_toplevel (PanelToplevel *toplevel)
+get_theme_settings_for_toplevel (PanelToplevel *toplevel)
 {
 	char      *toplevel_settings_path;
 	GSettings *settings;
-	GSettings *settings_background;
+	GSettings *theme;
 
 	g_object_get (toplevel, "settings-path", &toplevel_settings_path, NULL);
 	settings = g_settings_new_with_path (PANEL_TOPLEVEL_SCHEMA,
 					     toplevel_settings_path);
-	settings_background = g_settings_get_child (settings,
-						    PANEL_BACKGROUND_SCHEMA_CHILD);
+	theme = g_settings_get_child (settings, "theme");
 
 	g_object_unref (settings);
 	g_free (toplevel_settings_path);
 
-	return settings_background;
+	return theme;
 }
 
 static gboolean
@@ -393,21 +351,18 @@ set_background_image_from_uri (PanelToplevel *toplevel,
 	}
 	g_object_unref (file);
 
-	settings = get_settings_background_for_toplevel (toplevel);
+	settings = get_theme_settings_for_toplevel (toplevel);
 
-	if (!g_settings_is_writable (settings,
-				     PANEL_BACKGROUND_TYPE_KEY) ||
-	    !g_settings_is_writable (settings,
-				     PANEL_BACKGROUND_IMAGE_URI_KEY)) {
+	if (!g_settings_is_writable (settings, "custom-bg-image") ||
+	    !g_settings_is_writable (settings, "bg-image")) {
 		g_object_unref (settings);
 		return FALSE;
 	}
 
-	g_settings_set_string (settings, PANEL_BACKGROUND_IMAGE_URI_KEY, uri);
-	g_settings_set_enum (settings, PANEL_BACKGROUND_TYPE_KEY, PANEL_BACK_IMAGE);
+	g_settings_set_enum (settings, "custom-bg-image", TRUE);
+	g_settings_set_string (settings, "bg-image", uri);
 
 	g_object_unref (settings);
-
 	return FALSE;
 }
 
@@ -422,12 +377,10 @@ set_background_color (PanelToplevel *toplevel,
 	if (!dropped)
 		return FALSE;
 
-	settings = get_settings_background_for_toplevel (toplevel);
+	settings = get_theme_settings_for_toplevel (toplevel);
 
-	if (!g_settings_is_writable (settings,
-				     PANEL_BACKGROUND_TYPE_KEY) ||
-	    !g_settings_is_writable (settings,
-				     PANEL_BACKGROUND_COLOR_KEY)) {
+	if (!g_settings_is_writable (settings, "custom-bg-color") ||
+	    !g_settings_is_writable (settings, "bg-color")) {
 		g_object_unref (settings);
 		return FALSE;
 	}
@@ -439,12 +392,11 @@ set_background_color (PanelToplevel *toplevel,
 
 	color_str = gdk_rgba_to_string (&color);
 
-	g_settings_set_string (settings, PANEL_BACKGROUND_COLOR_KEY, color_str);
-	g_settings_set_enum (settings, PANEL_BACKGROUND_TYPE_KEY, PANEL_BACK_COLOR);
-
+	g_settings_set_boolean (settings, "custom-bg-color", TRUE);
+	g_settings_set_string (settings, "bg-color", color_str);
 	g_free (color_str);
-	g_object_unref (settings);
 
+	g_object_unref (settings);
 	return TRUE;
 }
 
@@ -453,16 +405,14 @@ reset_background (PanelToplevel *toplevel)
 {
 	GSettings *settings;
 
-	settings = get_settings_background_for_toplevel (toplevel);
+	settings = get_theme_settings_for_toplevel (toplevel);
 
-	if (!g_settings_is_writable (settings,
-				     PANEL_BACKGROUND_TYPE_KEY)) {
+	if (!g_settings_is_writable (settings, "custom-bg-image")) {
 		g_object_unref (settings);
 		return FALSE;
 	}
 
-	g_settings_set_enum (settings, PANEL_BACKGROUND_TYPE_KEY, PANEL_BACK_NONE);
-
+	g_settings_set_boolean (settings, "custom-bg-image", FALSE);
 	g_object_unref (settings);
 
 	return TRUE;
@@ -597,13 +547,13 @@ drop_nautilus_desktop_uri (PanelWidget         *panel,
 					   "OAFIID:GNOME_Panel_TrashApplet");
 	else if (strncmp (basename, "home", strlen ("home")) == 0) {
 		char  *name;
-		char  *uri;
+		char  *uri_tmp;
 		GFile *file;
 
 		file = g_file_new_for_path (g_get_home_dir ());
-		uri = g_file_get_uri (file);
-		name = panel_util_get_label_for_uri (uri);
-		g_free (uri);
+		uri_tmp = g_file_get_uri (file);
+		name = panel_util_get_label_for_uri (uri_tmp);
+		g_free (uri_tmp);
 		g_object_unref (file);
 
 		panel_launcher_create_from_info (panel->toplevel,
@@ -965,17 +915,17 @@ static GtkTargetList *
 get_target_list (void)
 {
 	static GtkTargetEntry drop_types [] = {
-		{ "text/uri-list",                       0, TARGET_URL },
-		{ "x-url/http",                          0, TARGET_NETSCAPE_URL },
-		{ "x-url/ftp",                           0, TARGET_NETSCAPE_URL },
-		{ "_NETSCAPE_URL",                       0, TARGET_NETSCAPE_URL },
-		{ "application/x-panel-directory",       0, TARGET_DIRECTORY },
-		{ "application/x-panel-applet-iid",      0, TARGET_APPLET },
-		{ "application/x-panel-applet-internal", 0, TARGET_APPLET_INTERNAL },
-		{ "application/x-panel-icon-internal",   0, TARGET_ICON_INTERNAL },
-		{ "application/x-color",                 0, TARGET_COLOR },
-		{ "property/bgimage",                    0, TARGET_BGIMAGE },
-		{ "x-special/gnome-reset-background",    0, TARGET_BACKGROUND_RESET },
+		{ (gchar *) "text/uri-list",                       0, TARGET_URL },
+		{ (gchar *) "x-url/http",                          0, TARGET_NETSCAPE_URL },
+		{ (gchar *) "x-url/ftp",                           0, TARGET_NETSCAPE_URL },
+		{ (gchar *) "_NETSCAPE_URL",                       0, TARGET_NETSCAPE_URL },
+		{ (gchar *) "application/x-panel-directory",       0, TARGET_DIRECTORY },
+		{ (gchar *) "application/x-panel-applet-iid",      0, TARGET_APPLET },
+		{ (gchar *) "application/x-panel-applet-internal", 0, TARGET_APPLET_INTERNAL },
+		{ (gchar *) "application/x-panel-icon-internal",   0, TARGET_ICON_INTERNAL },
+		{ (gchar *) "application/x-color",                 0, TARGET_COLOR },
+		{ (gchar *) "property/bgimage",                    0, TARGET_BGIMAGE },
+		{ (gchar *) "x-special/gnome-reset-background",    0, TARGET_BACKGROUND_RESET },
 	};
 	static GtkTargetList *target_list = NULL;
 
@@ -1257,10 +1207,6 @@ panel_widget_setup(PanelWidget *panel)
 			  "applet_move",
 			  G_CALLBACK(panel_applet_move),
 			  NULL);
-	g_signal_connect (G_OBJECT (panel),
-			  "back_change",
-			  G_CALLBACK (panel_back_change),
-			  NULL);
 }
 
 PanelData *
